import { StyleSettings, ExpressiveCodeTheme, ResolvedCoreStyles, ExpressiveCodePlugin, AttachedPluginData } from '@expressive-code/core';

type MarkerType = 'mark' | 'ins' | 'del';

declare const textMarkersStyleSettings: StyleSettings<"lineMarkerAccentMargin" | "lineMarkerAccentWidth" | "lineDiffIndicatorMarginLeft" | "inlineMarkerBorderWidth" | "inlineMarkerBorderRadius" | "inlineMarkerPadding" | "markHue" | "insHue" | "delHue" | "defaultChroma" | "defaultLuminance" | "backgroundOpacity" | "borderLuminance" | "borderOpacity" | "indicatorLuminance" | "indicatorOpacity" | "insDiffIndicatorContent" | "delDiffIndicatorContent" | "markBackground" | "markBorderColor" | "insBackground" | "insBorderColor" | "insDiffIndicatorColor" | "delBackground" | "delBorderColor" | "delDiffIndicatorColor">;
/**
 * Attempts to get background color values per marker type.
 * These colors are used for calculating contrast ratios.
 *
 * Usually, these are either the colors defined in `textMarkersStyleSettings`,
 * or style overrides provided by the user.
 *
 * One notable exception is that if non-color values (e.g. CSS variables)
 * were provided, the default colors will be returned instead. This is because
 * we can't reliably determine the actual color values from CSS variables.
 */
declare function getMarkerTypeColorsForContrastCalculation({ theme, coreStyles, styleOverrides, }: {
    theme: ExpressiveCodeTheme;
    coreStyles: ResolvedCoreStyles;
    styleOverrides?: Partial<typeof textMarkersStyleSettings.defaultSettings> | undefined;
}): {
    mark: string;
    ins: string;
    del: string;
};

interface PluginTextMarkersOptions {
    styleOverrides?: Partial<typeof textMarkersStyleSettings.defaultSettings> | undefined;
}
declare function pluginTextMarkers(options?: PluginTextMarkersOptions): ExpressiveCodePlugin;
interface PluginTextMarkersData {
    plaintextTerms: {
        markerType: MarkerType;
        text: string;
    }[];
    regExpTerms: {
        markerType: MarkerType;
        regExp: RegExp;
    }[];
    markerTypeColors?: ReturnType<typeof getMarkerTypeColorsForContrastCalculation> | undefined;
    originalLanguage?: string | undefined;
}
declare const pluginTextMarkersData: AttachedPluginData<PluginTextMarkersData>;

export { PluginTextMarkersData, PluginTextMarkersOptions, pluginTextMarkers, pluginTextMarkersData };
